@@ -50,9 +50,7 @@ class Statbotics:
         return out
 
     def _get(self, url, fields, retry=0):
-        print(url)
         resp = self.session.get(self.BASE_URL + url)
-        print(resp.json())
         if resp.status_code != 200:
             if retry < 2:
                 return self._get(url, fields, retry=retry + 1)
